@@ -1,5 +1,5 @@
 /*
- * $Id: arj.c,v 1.12 2004/05/01 15:29:02 andrew_belov Exp $
+ * $Id: arj.c,v 1.13 2005/06/21 19:53:13 andrew_belov Exp $
  * ---------------------------------------------------------------------------
  * This is  the main file of the  ARJ project. The  routines in this file have
  * a wide variety of purposes, however, all archive-related procedures are NOT
@@ -744,7 +744,7 @@ int main(int argc, char *argv[])
  params_max=argc+PARAMS_MAX;
  order=NULL;
  f_arg_array=NULL;
- #ifdef TZ_VAR
+ #ifdef USE_TZSET
   tzset();
  #endif
  ticks=get_ticks();
