@@ -1,5 +1,5 @@
 /*
- * $Id: arj_arcv.c,v 1.15 2004/06/18 16:19:37 andrew_belov Exp $
+ * $Id: arj_arcv.c,v 1.16 2005/06/21 19:53:13 andrew_belov Exp $
  * ---------------------------------------------------------------------------
  * Archive management routines  are stored here (all these have  nothing to do
  * neither with commands nor with the "user" part).
@@ -401,7 +401,7 @@ int read_header(int first)
    }
   }
  #endif
- if(check_file_size())
+ if(!first&&check_file_size())
   display_hdr_error(M_BAD_HEADER, NULL);
  #if SFX_LEVEL>=ARJSFXV
   file_garbled=(arj_flags&GARBLED_FLAG)?1:0;
