@@ -1,5 +1,5 @@
 /*
- * $Id: arj_file.c,v 1.9 2004/06/18 16:19:37 andrew_belov Exp $
+ * $Id: arj_file.c,v 1.10 2005/06/21 19:53:13 andrew_belov Exp $
  * ---------------------------------------------------------------------------
  * Various archive-management functions (mostly, file-related ones) are stored
  * here.
@@ -655,7 +655,7 @@ int query_action(int def, int qtype, FMSG *query)
   if((tmp_stdout=new_stdout)==new_stderr)
    new_stdout=stderr;
   result=query_action_proc(def, qtype, nquery=malloc_fmsg(query));
-  free(nquery);
+  free_fmsg(nquery);
   new_stdout=tmp_stdout;
   return(result);
  #else
@@ -676,7 +676,7 @@ int pause()
  tmp_query=malloc_fmsg(M_PRESS_ENTER);
  rc=query_action_proc(1, QUERY_PRESS_ENTER, tmp_query);
  new_stdout=tmp_stdout;
- free(tmp_query);
+ free_fmsg(tmp_query);
  return(rc);
 }
 
@@ -966,7 +966,7 @@ void display_indicator(long bytes)
 
 static int arj_putc(unsigned char c, int p)
 {
- unsigned char t[8];
+ unsigned char t[TAB_POS+1];
  unsigned char *q;
  int rc=p;
 
@@ -1010,7 +1010,7 @@ static int arj_putc(unsigned char c, int p)
 
 static int list_with_more(char *str, unsigned int len)
 {
- char i_field[CONSOLE_LINE_LENGTH+1];   /* Input field */
+ FMSG *prompt;
  char *sptr;
  unsigned int i;
  int cur_pos;
@@ -1023,14 +1023,14 @@ static int list_with_more(char *str, unsigned int len)
    fputc(CR, stdout);
  #endif
  sptr=str;
- far_strcpy((char FAR *)i_field, prompt_for_more?M_QUERY_MORE:M_QUERY_SCANNED_ENOUGH);
+ prompt=prompt_for_more?M_QUERY_MORE:M_QUERY_SCANNED_ENOUGH;
  nputlf();
  cur_line=2;
  cur_pos=1;
  i=1;
  while(i<=len)
  {
-  c=*(sptr++);
+  c=*sptr++;
   if(verbose_display==VERBOSE_NONE&&!help_issued)
    c&=0x7F;                             /* Strip high bit from nonlocal text */
   i++;
@@ -1043,12 +1043,12 @@ static int list_with_more(char *str, unsigned int len)
    if(cur_line>=lines_per_page-2)
    {
     cur_line=0;
-    sf=(yes_on_all_queries|skip_scanned_query);
+    sf=yes_on_all_queries||skip_scanned_query;
     if(!sf)
     {
-     sf=query_action(REPLY_NO, QUERY_SCANNED_ENOUGH, i_field);
+     sf=query_action(REPLY_NO, QUERY_SCANNED_ENOUGH, prompt);
      if(prompt_for_more)
-      sf^=1;
+      sf=!sf;
     }
     if(sf)
      return(1);
@@ -1057,12 +1057,12 @@ static int list_with_more(char *str, unsigned int len)
  }
  if(help_issued)
   return(0);
- sf=(yes_on_all_queries|skip_scanned_query);
+ sf=yes_on_all_queries||skip_scanned_query;
  if(!sf)
  {
-  sf=query_action(REPLY_NO, QUERY_SCANNED_ENOUGH, i_field);
+  sf=query_action(REPLY_NO, QUERY_SCANNED_ENOUGH, prompt);
   if(prompt_for_more)
-   sf^=1;
+   sf=!sf;
  }
  return(sf);
 }
