@@ -1,5 +1,5 @@
 /*
- * $Id: arj_proc.c,v 1.15 2004/06/18 16:19:37 andrew_belov Exp $
+ * $Id: arj_proc.c,v 1.18 2005/06/21 19:53:13 andrew_belov Exp $
  * ---------------------------------------------------------------------------
  * This file  contains many  of the functions  that  are called by various ARJ
  * modules. Everything is OS-independent, all OS-dependent  procedures must be
@@ -194,7 +194,7 @@ void append_curtime_proc()
  int doy;                               /* Day of year */
 
  curtime=time(NULL);
- tms=localtime(&curtime);
+ tms=arj_localtime(&curtime);
  doy=day_of_year(tms);
  sprintf(time_pad, time_tail_pattern, tms->tm_year+1900, tms->tm_mon+1,
          tms->tm_mday, doy, tms->tm_hour, tms->tm_min, tms->tm_sec);
@@ -304,7 +304,7 @@ void convert_time_limits()
  {
   tmp_ts=strtoul(timestr_newer, &cptr, 10)*(-86400L);
   ts=sum_time(tmp_ts, time(NULL));
-  tms=localtime(&ts);
+  tms=arj_localtime(&ts);
   if(tms==NULL)                         /* ASR fix 21/02/2001 -- IBM LIBC */
    error(M_INVALID_DATE);
   sprintf(misc_buf, date_digit_format, tms->tm_year+1900, tms->tm_mon+1, tms->tm_mday);
@@ -314,7 +314,7 @@ void convert_time_limits()
  {
   tmp_ts=strtoul(timestr_older, &cptr, 10)*(-86400L);
   ts=sum_time(tmp_ts, time(NULL));
-  tms=localtime(&ts);
+  tms=arj_localtime(&ts);
   if(tms==NULL)                         /* ASR fix 21/02/2001 -- IBM LIBC */
    error(M_INVALID_DATE);
   sprintf(misc_buf, date_digit_format, tms->tm_year+1900, tms->tm_mon+1, tms->tm_mday);
@@ -327,7 +327,7 @@ void convert_time_limits()
  if(timestr_older[0]=='\0'&&timestr_newer[0]=='\0')
  {
   ts=time(NULL);
-  tms=localtime(&ts);
+  tms=arj_localtime(&ts);
   make_timestamp(&arj_ts, tms->tm_year, tms->tm_mon+1, tms->tm_mday, 0, 0, 0);
   if(timestr_newer[0]=='\0')
    tested_ftime_newer=arj_ts;
@@ -1691,7 +1691,7 @@ void analyze_arg(char *sw)
     {
      done=1;
      store_by_suffix=1;
-     free(archive_suffixes);
+     free_fmsg(archive_suffixes);
      archive_suffixes=swptr;
     }
     else if(jswitch&&c=='W'&&sw_tail)
@@ -1930,12 +1930,6 @@ void analyze_arg(char *sw)
     }
    #endif
   }
-  /* This will become obsolete as COLOR_OUTPUT has changed the semantics of
-     quiet_mode - ASR fix 23/01/2003 */
-#ifndef COLOR_OUTPUT
-  if(quiet_mode&&!arjdisp_enabled)
-   quiet_mode=0;
-#endif
  }
 }
 
