@@ -1,5 +1,5 @@
 /*
- * $Id: environ.h,v 1.14 2004/05/31 16:08:41 andrew_belov Exp $
+ * $Id: environ.h,v 1.15 2005/06/21 19:53:14 andrew_belov Exp $
  * ---------------------------------------------------------------------------
  * All environment-specific declarations are held here.
  *
@@ -812,12 +812,18 @@ extern char root_wildcard[];
  #define strncmp_os(s1, s2, l) strncmp(s1, s2, l)
 #endif
 
-/* IBM's implementation of XPG4 CRT (LIBCS.DLL in OS/2) can't do localtime() properly.
-   So we expose a timezone variable and use a homebrew implementation. May be used as a
-   macro, i.e. real timezone converted to seconds. */
+/* "Year 2038" workaround. */
 
 #if (defined(LIBC)&&TARGET==OS2)||TARGET==WIN32
- #define TZ_VAR             _timezone
+ /* Certain LIBC runtimes fail to do localtime() properly when the time
+    argument exceeds 0x80000000 (a "year 2038" problem). So there is a
+    workaround routine, arj_localtime(), to help with this. */
+ #define USE_TZSET                      /* Req'd at least by LIBC on OS/2 */
+ #define LOCALTIME_WORKAROUND           /* Substitute our routine */
+ struct tm *arj_localtime(const time_t *tt);
+#else
+ /* No workaround required */
+ #define arj_localtime localtime
 #endif
 
 /* fchmod() to make SFX'es executable and other archives non-executable */
