@@ -1,5 +1,5 @@
 /*
- * $Id: rearj.c,v 1.10 2004/05/31 16:08:41 andrew_belov Exp $
+ * $Id: rearj.c,v 1.11 2005/06/21 19:53:14 andrew_belov Exp $
  * ---------------------------------------------------------------------------
  * This is the main file of the REARJ utility.
  *
@@ -1295,7 +1295,7 @@ int main(int argc, char **argv)
  no_colors=redirected=!is_tty(stdout);
 #endif
  msg_cprintf(0, M_REARJ_BANNER, build_date);
- #ifdef TZ_VAR
+ #ifdef USE_TZSET
   tzset();
  #endif
  build_crc32_table();
